Welcome to QPrism's documentation!
===================================

The **QPrism** Python package serves as a quality assessment toolbox for data collected using sensors in 
smartphones and wearables (eg. accelerometer, gyroscope, audio and video). The package leverages digital signal and image processing techniques 
along with machine learning algorithms to assess the quality of sensor data covering 
data availability, interpretability, noise contamination and consistency. 
QPrism is completely data-driven, requiring no a priori data assumptions or application-specific parameter tuning 
to generate a comprehensive data quality report.

Check out the :doc:`usage` section for further information, including
the :ref:`install` of the project.

.. note::

   This project is under active development.

Contents
--------

.. toctree::
   inplementation
   usage
   api
   glossary
   Git repo <https://github.com/aid4mh/QPrism>

Acknowledgements
----------------

Supported by CAMH / Krembil Center of Neuroinformatics. 

The authors also like to acknowledge Aditi Surendra for designing the module function illustration.

Contribution
------------

We welcome and encourage project contributions! Please see the `here <https://github.com/aid4mh/QPrism/blob/main/CONTRIBUTING.md>`_ for details.

License
-------

MIT License

Copyright (c) 2022 CAMH / Krembil Center of Neuroinformatics

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.